@@ -9,10 +9,10 @@ from .log import logger
 from .packer import _Packer
 from aiozmq import interface
 
-if hasattr(asyncio, 'ensure_future'):
+if hasattr(asyncio, "ensure_future"):
     ensure_future = asyncio.ensure_future
 else:  # Deprecated since Python version 3.4.4.
-    ensure_future = getattr(asyncio, 'async')
+    ensure_future = getattr(asyncio, "async")
 
 
 class Error(Exception):
@@ -29,9 +29,9 @@ class GenericError(Error):
         self.exc_repr = exc_repr
 
     def __repr__(self):
-        return '<Generic RPC Error {}{}: {}>'.format(self.exc_type,
-                                                     self.arguments,
-                                                     self.exc_repr)
+        return "<Generic RPC Error {}{}: {}>".format(
+            self.exc_type, self.arguments, self.exc_repr
+        )
 
 
 class NotFoundError(Error, LookupError):
@@ -40,7 +40,7 @@ class NotFoundError(Error, LookupError):
 
 class ParametersError(Error, ValueError):
     """Error raised by server when RPC method's parameters could not
-    be validated against their annotations."""
+    be validated against the signature."""
 
 
 class ServiceClosedError(Error):
@@ -77,22 +77,9 @@ class AttrHandler(AbstractHandler):
 
 
 def method(func):
-    """Marks a decorated function as RPC endpoint handler.
-
-    The func object may provide arguments and/or return annotations.
-    If so annotations should be callable objects and
-    they will be used to validate received arguments and/or return value.
-    """
+    """Marks a decorated function as an RPC endpoint handler."""
     func.__rpc__ = {}
-    func.__signature__ = sig = inspect.signature(func)
-    for name, param in sig.parameters.items():
-        ann = param.annotation
-        if ann is not param.empty and not callable(ann):
-            raise ValueError("Expected {!r} annotation to be callable"
-                             .format(name))
-    ann = sig.return_annotation
-    if ann is not sig.empty and not callable(ann):
-        raise ValueError("Expected return annotation to be callable")
+    func.__signature__ = inspect.signature(func)
     return func
 
 
@@ -130,17 +117,15 @@ class Service(asyncio.AbstractServer):
             return
         self._proto.transport.close()
 
-    @asyncio.coroutine
-    def wait_closed(self):
+    async def wait_closed(self):
         if self._proto.transport is None:
             return
         waiter = asyncio.Future(loop=self._loop)
         self._proto.done_waiters.append(waiter)
-        yield from waiter
+        await waiter
 
 
 class _BaseProtocol(interface.ZmqProtocol):
-
     def __init__(self, loop, *, translation_table=None):
         self.loop = loop
         self.transport = None
@@ -159,15 +144,19 @@ class _BaseProtocol(interface.ZmqProtocol):
 
 
 class _BaseServerProtocol(_BaseProtocol):
-
-    def __init__(self, loop, handler, *,
-                 translation_table=None,
-                 log_exceptions=False,
-                 exclude_log_exceptions=(),
-                 timeout=None):
+    def __init__(
+        self,
+        loop,
+        handler,
+        *,
+        translation_table=None,
+        log_exceptions=False,
+        exclude_log_exceptions=(),
+        timeout=None
+    ):
         super().__init__(loop, translation_table=translation_table)
         if not isinstance(handler, AbstractHandler):
-            raise TypeError('handler must implement AbstractHandler')
+            raise TypeError("handler must implement AbstractHandler")
         self.handler = handler
         self.log_exceptions = log_exceptions
         self.exclude_log_exceptions = exclude_log_exceptions
@@ -182,10 +171,10 @@ class _BaseServerProtocol(_BaseProtocol):
     def dispatch(self, name):
         if not name:
             raise NotFoundError(name)
-        namespaces, sep, method = name.rpartition('.')
+        namespaces, sep, method = name.rpartition(".")
         handler = self.handler
         if namespaces:
-            for part in namespaces.split('.'):
+            for part in namespaces.split("."):
                 try:
                     handler = handler[part]
                 except KeyError:
@@ -203,14 +192,14 @@ class _BaseServerProtocol(_BaseProtocol):
                 holder = func.__func__
             else:
                 holder = func
-            if not hasattr(holder, '__rpc__'):
+            if not hasattr(holder, "__rpc__"):
                 raise NotFoundError(name)
             return func
 
     def check_args(self, func, args, kwargs):
         """Utility function for validating function arguments
 
-        Returns validated (args, kwargs, return annotation) tuple
+        Returns validated (args, kwargs) tuple
         """
         try:
             sig = inspect.signature(func)
@@ -218,23 +207,7 @@ class _BaseServerProtocol(_BaseProtocol):
         except TypeError as exc:
             raise ParametersError(repr(exc)) from exc
         else:
-            arguments = bargs.arguments
-            marker = object()
-            for name, param in sig.parameters.items():
-                if param.annotation is param.empty:
-                    continue
-                val = arguments.get(name, marker)
-                if val is marker:
-                    continue  # Skip default value
-                try:
-                    arguments[name] = param.annotation(val)
-                except (TypeError, ValueError) as exc:
-                    raise ParametersError(
-                        'Invalid value for argument {!r}: {!r}'
-                        .format(name, exc)) from exc
-            if sig.return_annotation is not sig.empty:
-                return bargs.args, bargs.kwargs, sig.return_annotation
-            return bargs.args, bargs.kwargs, None
+            return bargs.args, bargs.kwargs
 
     def try_log(self, fut, name, args, kwargs):
         try:
@@ -244,16 +217,22 @@ class _BaseServerProtocol(_BaseProtocol):
                 for e in self.exclude_log_exceptions:
                     if isinstance(exc, e):
                         return
-                logger.exception(textwrap.dedent("""\
+                logger.exception(
+                    textwrap.dedent(
+                        """\
                     An exception %r from method %r call occurred.
                     args = %s
                     kwargs = %s
-                    """),
-                    exc, name,
-                    pprint.pformat(args), pprint.pformat(kwargs))  # noqa
+                    """
+                    ),
+                    exc,
+                    name,
+                    pprint.pformat(args),
+                    pprint.pformat(kwargs),
+                )  # noqa
 
     def add_pending(self, coro):
-        fut = ensure_future(coro, loop=self.loop)
+        fut = ensure_future(coro)
         self.pending_waiters.add(fut)
         return fut
 
