@@ -8,12 +8,19 @@ class ZmqStreamClosed(Exception):
     """A stream was closed"""
 
 
-@asyncio.coroutine
-def create_zmq_stream(zmq_type, *, bind=None, connect=None,
-                      loop=None, zmq_sock=None,
-                      high_read=None, low_read=None,
-                      high_write=None, low_write=None,
-                      events_backlog=100):
+async def create_zmq_stream(
+    zmq_type,
+    *,
+    bind=None,
+    connect=None,
+    loop=None,
+    zmq_sock=None,
+    high_read=None,
+    low_read=None,
+    high_write=None,
+    low_write=None,
+    events_backlog=100
+):
     """A wrapper for create_zmq_connection() returning a Stream instance.
 
     The arguments are all the usual arguments to create_zmq_connection()
@@ -32,15 +39,17 @@ def create_zmq_stream(zmq_type, *, bind=None, connect=None,
     """
     if loop is None:
         loop = asyncio.get_event_loop()
-    stream = ZmqStream(loop=loop, high=high_read, low=low_read,
-                       events_backlog=events_backlog)
-    tr, _ = yield from create_zmq_connection(
+    stream = ZmqStream(
+        loop=loop, high=high_read, low=low_read, events_backlog=events_backlog
+    )
+    tr, _ = await create_zmq_connection(
         lambda: stream._protocol,
         zmq_type,
         bind=bind,
         connect=connect,
         zmq_sock=zmq_sock,
-        loop=loop)
+        loop=loop,
+    )
     tr.set_write_buffer_limits(high_write, low_write)
     return stream
 
@@ -94,17 +103,16 @@ class ZmqStreamProtocol(ZmqProtocol):
         else:
             waiter.set_exception(exc)
 
-    @asyncio.coroutine
-    def _drain_helper(self):
+    async def _drain_helper(self):
         if self._connection_lost:
-            raise ConnectionResetError('Connection lost')
+            raise ConnectionResetError("Connection lost")
         if not self._paused:
             return
         waiter = self._drain_waiter
         assert waiter is None or waiter.cancelled()
         waiter = asyncio.Future(loop=self._loop)
         self._drain_waiter = waiter
-        yield from waiter
+        await waiter
 
     def msg_received(self, msg):
         self._stream.feed_msg(msg)
@@ -154,18 +162,17 @@ class ZmqStream:
     def get_extra_info(self, name, default=None):
         return self._transport.get_extra_info(name, default)
 
-    @asyncio.coroutine
-    def drain(self):
+    async def drain(self):
         """Flush the write buffer.
 
         The intended use is to write
 
           w.write(data)
-          yield from w.drain()
+          await w.drain()
         """
         if self._exception is not None:
             raise self._exception
-        yield from self._protocol._drain_helper()
+        await self._protocol._drain_helper()
 
     def exception(self):
         return self._exception
@@ -188,20 +195,19 @@ class ZmqStream:
 
     def set_transport(self, transport):
         """Private"""
-        assert self._transport is None, 'Transport already set'
+        assert self._transport is None, "Transport already set"
         self._transport = transport
 
     def _set_read_buffer_limits(self, high=None, low=None):
         if high is None:
             if low is None:
-                high = 64*1024
+                high = 64 * 1024
             else:
-                high = 4*low
+                high = 4 * low
         if low is None:
             low = high // 4
         if not high >= low >= 0:
-            raise ValueError('high (%r) must be >= low (%r) must be >= 0' %
-                             (high, low))
+            raise ValueError("high (%r) must be >= low (%r) must be >= 0" % (high, low))
         self._high_water = high
         self._low_water = low
 
@@ -237,7 +243,7 @@ class ZmqStream:
 
     def feed_msg(self, msg):
         """Private"""
-        assert not self._closing, 'feed_msg after feed_closing'
+        assert not self._closing, "feed_msg after feed_closing"
 
         msg_len = sum(len(i) for i in msg)
         self._queue.append((msg_len, msg))
@@ -248,15 +254,17 @@ class ZmqStream:
             self._waiter = None
             if not waiter.cancelled():
                 waiter.set_result(None)
-        if (self._transport is not None and
-                not self._paused and
-                self._queue_len > self._high_water):
+        if (
+            self._transport is not None
+            and not self._paused
+            and self._queue_len > self._high_water
+        ):
             self._transport.pause_reading()
             self._paused = True
 
     def feed_event(self, event):
         """Private"""
-        assert not self._closing, 'feed_event after feed_closing'
+        assert not self._closing, "feed_event after feed_closing"
 
         self._event_queue.append(event)
 
@@ -266,8 +274,7 @@ class ZmqStream:
             if not event_waiter.cancelled():
                 event_waiter.set_result(None)
 
-    @asyncio.coroutine
-    def read(self):
+    async def read(self):
         if self._exception is not None:
             raise self._exception
 
@@ -276,11 +283,13 @@ class ZmqStream:
 
         if not self._queue_len:
             if self._waiter is not None:
-                raise RuntimeError('read called while another coroutine is '
-                                   'already waiting for incoming data')
+                raise RuntimeError(
+                    "read called while another coroutine is "
+                    "already waiting for incoming data"
+                )
             self._waiter = asyncio.Future(loop=self._loop)
             try:
-                yield from self._waiter
+                await self._waiter
             finally:
                 self._waiter = None
 
@@ -289,18 +298,19 @@ class ZmqStream:
         self._maybe_resume_transport()
         return msg
 
-    @asyncio.coroutine
-    def read_event(self):
+    async def read_event(self):
         if self._closing:
             raise ZmqStreamClosed()
 
         if not self._event_queue:
             if self._event_waiter is not None:
-                raise RuntimeError('read_event called while another coroutine'
-                                   ' is already waiting for incoming data')
+                raise RuntimeError(
+                    "read_event called while another coroutine"
+                    " is already waiting for incoming data"
+                )
             self._event_waiter = asyncio.Future(loop=self._loop)
             try:
-                yield from self._event_waiter
+                await self._event_waiter
             finally:
                 self._event_waiter = None
 
